@@ -22,4 +22,4 @@ my $worksheet4 = $workbook->add_worksheet();
 # Worksheet1 will have the default tab colour.
 $worksheet2->set_tab_color( 'red' );
 $worksheet3->set_tab_color( 'green' );
-$worksheet4->set_tab_color( 0x35 );    # Orange
+$worksheet4->set_tab_color( '#FF6600'); # Orange
